==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Fem/App/FemSetObject.h <==
/***************************************************************************
 *   Copyright (c) 2013 Jürgen Riegel <FreeCAD@juergen-riegel.net>         *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef Fem_FemSetObject_H
#define Fem_FemSetObject_H

#include <App/DocumentObject.h>
#include <App/PropertyLinks.h>
#include <Mod/Fem/FemGlobal.h>

namespace Fem
{

class FemExport FemSetObject : public App::DocumentObject
{
    PROPERTY_HEADER(Fem::FemSetObject);

public:
    /// Constructor
    FemSetObject(void);
    virtual ~FemSetObject();

    App::PropertyLink FemMesh;

    /// returns the type name of the ViewProvider
    //virtual const char* getViewProviderName(void) const {
    //    return "FemGui::ViewProviderFemSet";
    //}
    virtual App::DocumentObjectExecReturn *execute(void) {
        return App::DocumentObject::StdReturn;
    }
    virtual short mustExecute(void) const;
    virtual PyObject *getPyObject(void);


};

} //namespace Fem


#endif // Fem_FemSetObject_H

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Fem/App/FemSetObject.h <==
/***************************************************************************
 *   Copyright (c) 2013 Jürgen Riegel <FreeCAD@juergen-riegel.net>         *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef Fem_FemSetObject_H
#define Fem_FemSetObject_H

#include <App/DocumentObject.h>
#include <App/PropertyLinks.h>
#include <Mod/Fem/FemGlobal.h>

namespace Fem
{

class FemExport FemSetObject : public App::DocumentObject
{
    PROPERTY_HEADER_WITH_OVERRIDE(Fem::FemSetObject);

public:
    /// Constructor
    FemSetObject();
    ~FemSetObject() override;

    App::PropertyLink FemMesh;

    /// returns the type name of the ViewProvider
    //virtual const char* getViewProviderName(void) const {
    //    return "FemGui::ViewProviderFemSet";
    //}
    App::DocumentObjectExecReturn *execute() override {
        return App::DocumentObject::StdReturn;
    }
    short mustExecute() const override;
    PyObject *getPyObject() override;


};

} //namespace Fem


#endif // Fem_FemSetObject_H
